@@ -35,6 +35,28 @@ nnf_dropout <- function(input, p = 0.5, training = TRUE, inplace = FALSE) {
 #'
 #' @export
 nnf_dropout2d <- function(input, p = 0.5, training = TRUE, inplace = FALSE) {
+  inp_dim <- input$dim()
+  
+  if (!inp_dim %in% c(3,4)) {
+    warn(
+      "dropout2d: Received a {inp_dim}-D input to dropout2d, which is deprecated ",
+      "and will result in an error in a future release. To retain the behavior ",
+      "and silence this warning, please use dropout instead. Note that dropout2d ",
+      "exists to provide channel-wise dropout on inputs with 2 spatial dimensions, ",
+      "a channel dimension, and an optional batch dimension (i.e. 3D or 4D inputs)."
+    )
+  }
+  
+  if (inp_dim == 3) {
+    warn(
+      "dropout2d: Received a 3D input to dropout2d and assuming that channel-wise ",
+      "1D dropout behavior is desired - input is interpreted as shape (N, C, L), where C ",
+      "is the channel dim. This behavior will change in a future release to interpret the ",
+      "input as one without a batch dimension, i.e. shape (C, H, W). To maintain the 1D ",
+      "channel-wise dropout behavior, please switch to using dropout1d instead."
+    )
+  }
+  
   if (inplace) {
     torch_feature_dropout_(input, p, training)
   } else {
