@@ -28,29 +28,35 @@ expect_optim_works <- function(optim, defaults) {
     opt$step(fn)
   }
 
-
   expect_true(as_array(fn()) <= as_array(initial_value) / 2)
 
   opt$state_dict()
 }
 
-expect_state_is_updated <- function(opt_fn) {
+expect_state_is_updated <- function(opt_fn, ...) {
   x <- torch_tensor(1, requires_grad = TRUE)
-  opt <- opt_fn(x)
+  opt <- opt_fn(x, ...)
   opt$zero_grad()
   y <- 2 * x
   y$backward()
   opt$step()
-  expect_equal(as.numeric(opt$state$get(opt$param_groups[[1]]$params[[1]])$step), 1)
+  # not all ignite optimizers have a step counter
+  if (!is.null(opt$state_dict()$state[[1]]$step)) {
+    expect_equal(as.numeric(opt$state_dict()$state[[1]]$step), 1)
+  }
   opt$step()
-  expect_equal(as.numeric(opt$state$get(opt$param_groups[[1]]$params[[1]])$step), 2)
+  if (!is.null(opt$state_dict()$state[[1]]$step)) {
+    expect_equal(as.numeric(opt$state_dict()$state[[1]]$step), 2)
+  }
 
   state <- opt$state_dict()
   x2 <- torch_tensor(1, requires_grad = TRUE)
-  opt2 <- opt_fn(x)
+  opt2 <- opt_fn(x, ...)
   opt2$load_state_dict(state)
 
-  for (i in seq_along(opt$state$map)) {
-    expect_equal(opt2$state$map[[i]], opt$state$map[[i]])
+  x1 = unlist(opt2$state_dict()$state)
+  x2 = unlist(opt$state_dict()$state)
+  for (i in seq_along(x1)) {
+    expect_equal(x1[[i]], x2[[i]])
   }
 }
